Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2658)

Unified Diff: dart/tests/language/invocation_mirror_invoke_on_test.dart

Issue 14251021: Move invokeOn to InstanceMirror. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/tests/language/invocation_mirror_invoke_on_test.dart
diff --git a/dart/tests/language/invocation_mirror_invoke_on_test.dart b/dart/tests/language/invocation_mirror_invoke_on_test.dart
index 4f84915e525ae8050996b7fd5f310bc3b6290410..fd6722a1e8d7acd4c075bf0184df11bbacea9706 100644
--- a/dart/tests/language/invocation_mirror_invoke_on_test.dart
+++ b/dart/tests/language/invocation_mirror_invoke_on_test.dart
@@ -2,9 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
+import "dart:mirrors" show reflect;
import "package:expect/expect.dart";
// Testing Invocation.invokeOn method; test of issue 7227.
var reachedSetX = 0;
var reachedGetX = 0;
@@ -25,7 +26,7 @@ class A {
class B {
final a = new A();
- noSuchMethod(mirror) => mirror.invokeOn(a);
+ noSuchMethod(mirror) => reflect(a).delegate(mirror);
}
main () {
@@ -2,9 +2,10 @@
import "package:expect/expect.dart";
-// Testing Invocation.invokeOn method; test of issue 7227.
+// Testing InstanceMirror.delegate method; test of issue 7227.
var reachedSetX = 0;
var reachedGetX = 0;

Powered by Google App Engine
This is Rietveld 408576698